import re

from jinja2 import pass_eval_context
from markupsafe import Markup, escape
from starlette.templating import Jinja2Templates


templates = Jinja2Templates(directory="templates")


@pass_eval_context
def nl2br(eval_ctx, value):
    br = "<br>\n"

    if eval_ctx.autoescape:
        value = escape(value)
        br = Markup(br)

    result = "\n\n".join(
        # need to convert p to Markup again after applying re.split(...)
        f"<p>{br.join(Markup(p).splitlines())}</p>"
        for p in re.split(r"(?:\r\n|\r(?!\n)|\n){2,}", value)
    )

    if eval_ctx.autoescape:
        result = Markup(result)

    return result


templates.env.filters["nl2br"] = nl2br
